==> plantuml-libs-7.1.0.tgz: package/distribution/azure-4/Item/Storage/ServiceDataLakeStorageGen1.md <==
# ServiceDataLakeStorageGen1


```text
azure-4/Item/Storage/ServiceDataLakeStorageGen1
```

```text
include('azure-4/Item/Storage/ServiceDataLakeStorageGen1')
```



| Illustration | ServiceDataLakeStorageGen1 | ServiceDataLakeStorageGen1Card | ServiceDataLakeStorageGen1Group |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../azure-4/Item/Storage/ServiceDataLakeStorageGen1.png) | ![illustration for ServiceDataLakeStorageGen1](../../../azure-4/Item/Storage/ServiceDataLakeStorageGen1.Local.png) | ![illustration for ServiceDataLakeStorageGen1Card](../../../azure-4/Item/Storage/ServiceDataLakeStorageGen1Card.Local.png) | ![illustration for ServiceDataLakeStorageGen1Group](../../../azure-4/Item/Storage/ServiceDataLakeStorageGen1Group.Local.png) |




## ServiceDataLakeStorageGen1

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceDataLakeStorageGen1
include('azure-4/Item/Storage/ServiceDataLakeStorageGen1')

' renders the element
ServiceDataLakeStorageGen1('ServiceDataLakeStorageGen1', 'Service Data Lake Storage Gen1', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceDataLakeStorageGen1
include('azure-4/Item/Storage/ServiceDataLakeStorageGen1')

' renders the element
ServiceDataLakeStorageGen1('ServiceDataLakeStorageGen1', 'Service Data Lake Storage Gen1', 'an optional tech label')
@enduml
```

## ServiceDataLakeStorageGen1Card

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceDataLakeStorageGen1Card
include('azure-4/Item/Storage/ServiceDataLakeStorageGen1')

' renders the element
ServiceDataLakeStorageGen1Card('ServiceDataLakeStorageGen1Card', 'Service Data Lake Storage Gen1 Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceDataLakeStorageGen1Card
include('azure-4/Item/Storage/ServiceDataLakeStorageGen1')

' renders the element
ServiceDataLakeStorageGen1Card('ServiceDataLakeStorageGen1Card', 'Service Data Lake Storage Gen1 Card', 'an optional description')
@enduml
```

## ServiceDataLakeStorageGen1Group

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceDataLakeStorageGen1Group
include('azure-4/Item/Storage/ServiceDataLakeStorageGen1')

' renders the element
ServiceDataLakeStorageGen1Group('ServiceDataLakeStorageGen1Group', 'Service Data Lake Storage Gen1 Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceDataLakeStorageGen1Group
include('azure-4/Item/Storage/ServiceDataLakeStorageGen1')

' renders the element
ServiceDataLakeStorageGen1Group('ServiceDataLakeStorageGen1Group', 'Service Data Lake Storage Gen1 Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-9.2.0.tgz: package/distribution/azure-4/Item/Storage/ServiceDataLakeStorageGen1.md <==
# ServiceDataLakeStorageGen1


```text
azure-4/Item/Storage/ServiceDataLakeStorageGen1
```

```text
include('azure-4/Item/Storage/ServiceDataLakeStorageGen1')
```



| Illustration | ServiceDataLakeStorageGen1 | ServiceDataLakeStorageGen1Card | ServiceDataLakeStorageGen1Group |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../azure-4/Item/Storage/ServiceDataLakeStorageGen1.png) | ![illustration for ServiceDataLakeStorageGen1](../../../azure-4/Item/Storage/ServiceDataLakeStorageGen1.Local.png) | ![illustration for ServiceDataLakeStorageGen1Card](../../../azure-4/Item/Storage/ServiceDataLakeStorageGen1Card.Local.png) | ![illustration for ServiceDataLakeStorageGen1Group](../../../azure-4/Item/Storage/ServiceDataLakeStorageGen1Group.Local.png) |




## ServiceDataLakeStorageGen1

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceDataLakeStorageGen1
include('azure-4/Item/Storage/ServiceDataLakeStorageGen1')

' renders the element
ServiceDataLakeStorageGen1('ServiceDataLakeStorageGen1', 'Service Data Lake Storage Gen1', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceDataLakeStorageGen1
include('azure-4/Item/Storage/ServiceDataLakeStorageGen1')

' renders the element
ServiceDataLakeStorageGen1('ServiceDataLakeStorageGen1', 'Service Data Lake Storage Gen1', 'an optional tech label', 'an optional description')
@enduml
```

## ServiceDataLakeStorageGen1Card

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceDataLakeStorageGen1Card
include('azure-4/Item/Storage/ServiceDataLakeStorageGen1')

' renders the element
ServiceDataLakeStorageGen1Card('ServiceDataLakeStorageGen1Card', 'Service Data Lake Storage Gen1 Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceDataLakeStorageGen1Card
include('azure-4/Item/Storage/ServiceDataLakeStorageGen1')

' renders the element
ServiceDataLakeStorageGen1Card('ServiceDataLakeStorageGen1Card', 'Service Data Lake Storage Gen1 Card', 'an optional description')
@enduml
```

## ServiceDataLakeStorageGen1Group

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceDataLakeStorageGen1Group
include('azure-4/Item/Storage/ServiceDataLakeStorageGen1')

' renders the element
ServiceDataLakeStorageGen1Group('ServiceDataLakeStorageGen1Group', 'Service Data Lake Storage Gen1 Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceDataLakeStorageGen1Group
include('azure-4/Item/Storage/ServiceDataLakeStorageGen1')

' renders the element
ServiceDataLakeStorageGen1Group('ServiceDataLakeStorageGen1Group', 'Service Data Lake Storage Gen1 Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
